/*!
 * Custom script to make jquery-ui dialog responsive.
 * Patch applied on jquery-ui dialog.
 * Patched by #RG20200720.
 * Inspired from :
 * http://stackoverflow.com/a/16471891/413538
 */
(function ($) {

	"use strict";

	var uiDialogFluidForce = 1; // = 1 : To activate fluid responsive on all UI Dialogs

	function fluidDialog() {
		var $visible = $(".ui-dialog:visible");
		// Each open dialog
		$visible.each(function () {
			var $this = $(this);
			var dialog = $this.find(".ui-dialog-content").data("ui-dialog");
			if(dialog.options.fluid || uiDialogFluidForce) {
				// Fix maxWidth bug.
				$this.css("max-width", dialog.options.maxWidth + "px");
				// Reposition dialog.
				dialog.option("position", dialog.options.position);
			}
		});
	}

	// Resize dialog on window resize.
	$(window).resize(function () {
		fluidDialog();
	});

	// Resize dialog if opened in a viewport smaller than dialog width.
	$(document).on("dialogopen", ".ui-dialog", function () {
		fluidDialog();
	});
})(jQuery);
